==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/PullRequestLint.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Configure validations to run on GitHub pull requests.
 * <p>
 * Only generates a file if at least one linter is configured.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.769Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestLint")
public class PullRequestLint extends io.github.cdklabs.projen.Component {

    protected PullRequestLint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PullRequestLint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestLint(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.PullRequestLintOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), options });
    }

    /**
     * @param github This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestLint(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.PullRequestLint}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.PullRequestLint> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private io.github.cdklabs.projen.github.PullRequestLintOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
        }

        /**
         * (experimental) Github Runner selection labels.
         * <p>
         * Default: ["ubuntu-latest"]
         * <p>
         * @return {@code this}
         * @param runsOn Github Runner selection labels. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(final java.util.List<java.lang.String> runsOn) {
            this.options().runsOn(runsOn);
            return this;
        }

        /**
         * (experimental) Validate that pull request titles follow Conventional Commits.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @see https://www.conventionalcommits.org/
         * @param semanticTitle Validate that pull request titles follow Conventional Commits. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitle(final java.lang.Boolean semanticTitle) {
            this.options().semanticTitle(semanticTitle);
            return this;
        }

        /**
         * (experimental) Options for validating the conventional commit title linter.
         * <p>
         * Default: - title must start with "feat", "fix", or "chore"
         * <p>
         * @return {@code this}
         * @param semanticTitleOptions Options for validating the conventional commit title linter. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitleOptions(final io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions) {
            this.options().semanticTitleOptions(semanticTitleOptions);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.github.PullRequestLint}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.PullRequestLint build() {
            return new io.github.cdklabs.projen.github.PullRequestLint(
                this.github,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.github.PullRequestLintOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.github.PullRequestLintOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/PullRequestLint.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Configure validations to run on GitHub pull requests.
 * <p>
 * Only generates a file if at least one linter is configured.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.435Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestLint")
public class PullRequestLint extends io.github.cdklabs.projen.Component {

    protected PullRequestLint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PullRequestLint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestLint(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.PullRequestLintOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), options });
    }

    /**
     * @param github This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestLint(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required") });
    }

    /**
     * (experimental) Called before synthesis.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void preSynthesize() {
        software.amazon.jsii.Kernel.call(this, "preSynthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.PullRequestLint}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.PullRequestLint> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private io.github.cdklabs.projen.github.PullRequestLintOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
        }

        /**
         * (experimental) Require a contributor statement to be included in the PR description.
         * <p>
         * For example confirming that the contribution has been made by the contributor and complies with the project's license.
         * <p>
         * Appends the statement to the end of the Pull Request template.
         * <p>
         * Default: - no contributor statement is required
         * <p>
         * @return {@code this}
         * @param contributorStatement Require a contributor statement to be included in the PR description. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contributorStatement(final java.lang.String contributorStatement) {
            this.options().contributorStatement(contributorStatement);
            return this;
        }

        /**
         * (experimental) Options for requiring a contributor statement on Pull Requests.
         * <p>
         * Default: - none
         * <p>
         * @return {@code this}
         * @param contributorStatementOptions Options for requiring a contributor statement on Pull Requests. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contributorStatementOptions(final io.github.cdklabs.projen.github.ContributorStatementOptions contributorStatementOptions) {
            this.options().contributorStatementOptions(contributorStatementOptions);
            return this;
        }

        /**
         * (experimental) Github Runner selection labels.
         * <p>
         * Default: ["ubuntu-latest"]
         * <p>
         * @return {@code this}
         * @param runsOn Github Runner selection labels. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(final java.util.List<java.lang.String> runsOn) {
            this.options().runsOn(runsOn);
            return this;
        }

        /**
         * (experimental) Github Runner Group selection options.
         * <p>
         * @return {@code this}
         * @param runsOnGroup Github Runner Group selection options. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOnGroup(final io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup) {
            this.options().runsOnGroup(runsOnGroup);
            return this;
        }

        /**
         * (experimental) Validate that pull request titles follow Conventional Commits.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @see <a href="https://www.conventionalcommits.org/">https://www.conventionalcommits.org/</a>
         * @param semanticTitle Validate that pull request titles follow Conventional Commits. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitle(final java.lang.Boolean semanticTitle) {
            this.options().semanticTitle(semanticTitle);
            return this;
        }

        /**
         * (experimental) Options for validating the conventional commit title linter.
         * <p>
         * Default: - title must start with "feat", "fix", or "chore"
         * <p>
         * @return {@code this}
         * @param semanticTitleOptions Options for validating the conventional commit title linter. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitleOptions(final io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions) {
            this.options().semanticTitleOptions(semanticTitleOptions);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.github.PullRequestLint}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.PullRequestLint build() {
            return new io.github.cdklabs.projen.github.PullRequestLint(
                this.github,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.github.PullRequestLintOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.github.PullRequestLintOptions.Builder();
            }
            return this.options;
        }
    }
}
